pub fn init(pmm: &Pmm, vmm: &Vmm)Expand description
Map the heap virtual address range to physical frames and initialize the allocator.
Panics
Panics with PanicCode::OutOfMemory if the PMM cannot satisfy any frame allocation.
pub fn init(pmm: &Pmm, vmm: &Vmm)Map the heap virtual address range to physical frames and initialize the allocator.
Panics with PanicCode::OutOfMemory if the PMM cannot satisfy any frame allocation.